@@ -32,6 +32,8 @@ def setup_boot_loader(stanzas):
         grub_file_path = "/target/usr/share/grub"
     elif os.path.isdir("/target/usr/lib/grub"):
         grub_file_path = "/target/usr/lib/grub"
+    elif os.path.isdir("/target/lib/grub"):
+        grub_file_path = "/target/lib/grub"
     else:
         raise RuntimeError, "cannot find GRUB boot files"
 
